<instructions>
Get the dimensions for specified metrics

Dimensions are the attributes, features, or characteristics
that describe or categorize data.
</instructions>

<parameters>
metrics: List of metric names
search: Optional string used to filter dimensions by name using partial matches (only use when absolutely necessary as some dimensions might be missed due to specific naming styles)
</parameters>